@@ -131,8 +131,6 @@
 #'   tmpdir <- tempdir2()
 #'   newModule("test", tmpdir, open = FALSE)
 #'   convertToPackage("test", path = tmpdir)
-#'   pkgload::load_all(file.path(tmpdir, "test"))
-#'   pkgload::unload("test")
 #' }
 #'
 convertToPackage <- function(module = NULL, path = getOption("spades.modulePath"),
@@ -145,13 +143,16 @@ convertToPackage <- function(module = NULL, path = getOption("spades.modulePath"
   mainModuleFile <- file.path(path, unlist(module), paste0(unlist(module), ".R"))
   packageFolderName <- dirname(mainModuleFile)
   aa <- parse(mainModuleFile, keep.source = TRUE)
-  rlaa <- readLines(mainModuleFile)
   gpd <- getParseData(aa)
 
+  rlaa <- readLines(mainModuleFile)
+
   defModule <- grepl("^defineModule", aa)
   whDefModule <- which(defModule)
   whNotDefModule <- which(!defModule)
 
+  linesWithDefModule <- gpd[grep("defineModule", gpd$text) - 1, ][, c("line1", "line2")]
+
   doEvent <- grepl(paste0("^doEvent.", module), aa)
   whDoEvent <- which(doEvent)
   whNoDoEvent <- which(!doEvent & !defModule)
@@ -168,153 +169,67 @@ convertToPackage <- function(module = NULL, path = getOption("spades.modulePath"
   linesWithRoxygen <- parseWithRoxygen[, "line1"]
   nextElement <- c(whNotDefModule[-1], Inf)
 
-  fileNames <- Map(element = whDefModule, nextElement = whNotDefModule[1],
-                   function(element, nextElement) {
-                     i <- 0
-                     fn <- filePath <- fnCh <- parseWithFn <- lineWithFn <- list()
-                     for (elem in c(element, nextElement)) {
-                       i <- i + 1
-                       if (is.infinite(elem)) {
-                         lineWithFn[[i]] <- length(rlaa) + 1
-                         break
-                       }
-                       fn[[i]] <- aa[[elem]][[2]]
-                       filePath[[i]] <- filenameFromFunction(packageFolderName, fn[[i]], "R")
-                       fnCh[[i]] <- as.character(fn[[i]])
-                       gpdLines <- which(gpd$text == fnCh[[i]] & gpd$token == "SYMBOL")
-                       if (length(gpdLines) > 1)
-                         for (gl in gpdLines) {
-                           line1 <- gpd[gl, "line1"]
-                           isTop <- any(gpd[gpd[, "line1"] == line1, "parent"] == 0)
-                           if (isTRUE(isTop)) {
-                             gpdLines <- gl
-                             break
-                           }
-                         }
-                       parseWithFn[[i]] <- gpd[gpdLines, ]
-                       lineWithFn[[i]] <- parseWithFn[[i]][, "line1"]
-                       if (length(lineWithFn[[i]]) > 1) {
-                         if (i == 1) {
-                           lineWithFn[[1]] <- lineWithFn[[1]][1]
-                         } else {
-                           whAfterLine1 <- which(lineWithFn[[2]] > lineWithFn[[1]])
-                           if (length(whAfterLine1))
-                             lineWithFn[[2]] <- lineWithFn[[2]][whAfterLine1[1]]
-                         }
-                       }
-                     }
-                     fn <- filenameForMainFunctions(module, path)
-                     cat("#' @export", file = fn, sep = "\n", append = FALSE)
-                     cat(rlaa[lineWithFn[[2]]:length(rlaa)],
-                         file = fn, sep = "\n", append = TRUE)
-                     cat(rlaa[1:(lineWithFn[[2]] - 1)], file = mainModuleFile,
-                         sep = "\n", append = FALSE)
-                   })
-
-  otherStuffFn <- filenameFromFunction(packageFolderName, "other", "R")
-  cat("
-makeActiveBinding('mod', SpaDES.core:::activeModBindingFunction, ",
-      paste0('asNamespace(SpaDES.core:::.moduleNameNoUnderscore(\'', module, '\'))'), ")
-
-makeActiveBinding('Par', SpaDES.core:::activeParBindingFunction, ",
-      paste0('asNamespace(SpaDES.core:::.moduleNameNoUnderscore(\'', module, '\'))'), ")
-
-", file = otherStuffFn)
-
-  if (length(linesWithRoxygen) > 0) {
-    message("There was some roxygen2 documentation that was not immediately above ",
-            "a function; it is being saved in R/documentation.R ... please confirm that ",
-            "the documentation is correct.")
-    cat(rlaa[linesWithRoxygen], file = filenameFromFunction(packageFolderName, "documentation", "R")
-        , sep = "\n", append = FALSE)
-    linesWithRoxygen <- character()
-  }
+  # fileNames <- Map(element = whDefModule, nextElement = whNotDefModule[1],
+  #                  function(element, nextElement) {
+  #                    i <- 0
+  #                    fn <- filePath <- fnCh <- parseWithFn <- lineWithFn <- list()
+  #                    for (elem in c(element, nextElement)) {
+  #                      i <- i + 1
+  #                      if (is.infinite(elem)) {
+  #                        lineWithFn[[i]] <- length(rlaa) + 1
+  #                        break
+  #                      }
+  #                      fn[[i]] <- aa[[elem]][[2]]
+  #                      filePath[[i]] <- filenameFromFunction(packageFolderName, fn[[i]], "R")
+  #                      fnCh[[i]] <- as.character(fn[[i]])
+  #                      gpdLines <- which(gpd$text == fnCh[[i]] & gpd$token == "SYMBOL")
+  #                      if (length(gpdLines) > 1)
+  #                        for (gl in gpdLines) {
+  #                          line1 <- gpd[gl, "line1"]
+  #                          isTop <- any(gpd[gpd[, "line1"] == line1, "parent"] == 0)
+  #                          if (isTRUE(isTop)) {
+  #                            gpdLines <- gl
+  #                            break
+  #                          }
+  #                        }
+  #                      parseWithFn[[i]] <- gpd[gpdLines, ]
+  #                      lineWithFn[[i]] <- parseWithFn[[i]][, "line1"]
+  #                      if (length(lineWithFn[[i]]) > 1) {
+  #                        if (i == 1) {
+  #                          lineWithFn[[1]] <- lineWithFn[[1]][1]
+  #                        } else {
+  #                          whAfterLine1 <- which(lineWithFn[[2]] > lineWithFn[[1]])
+  #                          if (length(whAfterLine1))
+  #                            lineWithFn[[2]] <- lineWithFn[[2]][whAfterLine1[1]]
+  #                        }
+  #                      }
+  #                    }
+  #                    fn <- filenameForMainFunctions(module, path)
+  #                    cat("#' @export", file = fn, sep = "\n", append = FALSE)
+  #                    cat(rlaa[lineWithFn[[2]]:length(rlaa)],
+  #                        file = fn, sep = "\n", append = TRUE)
+  #                    cat(rlaa[1:(lineWithFn[[2]] - 1)], file = mainModuleFile,
+  #                        sep = "\n", append = FALSE)
+  #                  })
 
   filePathImportSpadesCore <- filenameFromFunction(packageFolderName, "imports", "R")# file.path(dirname(mainModuleFile), "R", "imports.R")
 
-  # cat(format(aa[[whDefModule]]), file = mainModuleFile, sep = "\n")
   md <- aa[[whDefModule]][[3]]
   deps <- unlist(eval(md$reqdPkgs))
 
-
-  dFile <- DESCRIPTIONfileFromModule(module, md, deps, hasNamespaceFile, NAMESPACEFile, filePathImportSpadesCore,
-                                        packageFolderName)
-  # d <- list()
-  # d$Package <- .moduleNameNoUnderscore(module)
-  # d$Type <- "Package"
-  #
-  # d$Title <- md$name
-  # d$Description <- md$description
-  # d$Version <- as.character(eval(md$version[[2]]))
-  # d$Date <- Sys.Date()
-  # d$Authors <- md$authors
-  # d$Authors <- c(paste0("  ", format(d$Authors)[1]), format(d$Authors)[-1])
-  #
-  #
-  # hasSC <- grepl("SpaDES.core", deps)
-  # if (all(!hasSC))
-  #   deps <- c("SpaDES.core", deps)
-  #
-  # d$Imports <- Require::extractPkgName(deps)
-  # versionNumb <- Require::extractVersionNumber(deps)
-  # hasVersionNumb <- !is.na(versionNumb)
-  # inequality <- paste0("(", gsub("(.+)\\((.+)\\)", "\\2", deps[hasVersionNumb]), ")")
-  # missingSpace <- !grepl("[[:space:]]", inequality)
-  # if (any(missingSpace))
-  #   inequality[missingSpace] <- gsub("([=><]+)", "\\1 ", inequality[missingSpace])
-  #
-  # namespaceImports <- d$Imports
-  # # Create "import all" for each of the packages, unless it is already in an @importFrom
-  # if (hasNamespaceFile) {
-  #   nsTxt <- readLines(NAMESPACEFile)
-  #   hasImportFrom <- grepl("importFrom", nsTxt)
-  #   if (any(hasImportFrom)) {
-  #     pkgsNotNeeded <- unique(gsub(".+\\((.+)\\,.+\\)", "\\1", nsTxt[hasImportFrom]))
-  #     namespaceImports <- grep(paste(pkgsNotNeeded, collapse = "|"),
-  #                              namespaceImports, invert = TRUE, value = TRUE)
-  #   }
-  # }
-  #
-  # cat(paste0("#' @import ", namespaceImports, "\nNULL\n"), sep = "\n",
-  #     file = filePathImportSpadesCore, fill = TRUE)
-  #
-  # d$Imports[hasVersionNumb] <- paste(d$Imports[hasVersionNumb], inequality)
-  #
-  # dFile <- filenameFromFunction(packageFolderName, "DESCRIPTION", fileExt = "")
-  #
-  # cat(paste("Package:", d$Package), file = dFile, sep = "\n")
-  # cat(paste("Type:", d$Type), file = dFile, sep = "\n", append = TRUE)
-  # cat(paste("Title:", d$Title), file = dFile, sep = "\n", append = TRUE)
-  # cat(paste("Version:", d$Version), file = dFile, sep = "\n", append = TRUE)
-  # cat(paste("Description:", paste(d$Description, collapse = " ")), file = dFile, sep = "\n", append = TRUE)
-  # cat(paste("Date:", d$Date), file = dFile, sep = "\n", append = TRUE)
-  # cat(c("Authors@R:  ", format(d$Authors)), file = dFile, sep = "\n", append = TRUE)
-  #
-  # if (length(d$Imports))
-  #   cat(c("Imports:", paste("   ", d$Imports, collapse = ",\n")), sep = "\n", file = dFile, append = TRUE)
-  #
-  # Suggests <- c('knitr', 'rmarkdown')
-  # cat(c("Suggests:", paste("   ", Suggests, collapse = ",\n")), sep = "\n", file = dFile, append = TRUE)
-  #
-  # cat("Encoding: UTF-8", sep = "\n", file = dFile, append = TRUE)
-  # cat("License: GPL-3", sep = "\n", file = dFile, append = TRUE)
-  # cat("VignetteBuilder: knitr, rmarkdown", sep = "\n", file = dFile, append = TRUE)
-  # cat("ByteCompile: yes", sep = "\n", file = dFile, append = TRUE)
-  # cat("Roxygen: list(markdown = TRUE)", sep = "\n", file = dFile, append = TRUE)
-  #
-  #
-  # message("New/updated DESCRIPTION file is: ", dFile)
+  dFile <- DESCRIPTIONfileFromModule(
+    module, md, deps, hasNamespaceFile, NAMESPACEFile,
+    filePathImportSpadesCore, packageFolderName)
 
   if (isTRUE(buildDocuments)) {
-    message("Building documentation")
-    m <- packageFolderName
-    roxygen2::roxygenise(m, roclets = NULL) # This builds documentation, but also exports all functions ...
-    pkgload::dev_topic_index_reset(m)
-    pkgload::unload(.moduleNameNoUnderscore(basename2(m))) # so, unload here before reloading without exporting
+    documentModule(packageFolderName, gpd, linesWithDefModule)
   }
 
   RBuildIgnoreFile <- filenameFromFunction(packageFolderName, "", fileExt = ".Rbuildignore")
-  cat("^.*\\.Rproj$
+
+  startCat <- if (file.exists(RBuildIgnoreFile)) readLines(RBuildIgnoreFile) else character()
+
+  rbi <- paste("^.*\\.Rproj$
 ^\\.Rproj\\.user$
 ^_pkgdown\\.yml$
 .*\\.tar\\.gz$
@@ -324,6 +239,8 @@ makeActiveBinding('Par', SpaDES.core:::activeParBindingFunction, ",
 CONTRIBUTING\\.md
 cran-comments\\.md
 ^docs$
+citation.*
+figures
 ^LICENSE$
 vignettes/.*_cache$
 vignettes/.*\\.log$
@@ -335,9 +252,13 @@ vignettes/.*\\.log$
 ^data/*
 ^.git
 ^.gitignore
-^.gitmodules
-    ", sep = "\n",
-      file = RBuildIgnoreFile, fill = TRUE)
+^.gitmodules", sep = "\n")
+  rbi <- strsplit(rbi, split = "\n")[[1]]
+
+  modFiles <- c(paste0(module, ".*"), ".*zip")
+
+  rbi <- unique(c(startCat, rbi, modFiles))
+  cat(rbi, file = RBuildIgnoreFile, fill = TRUE, sep = "\n")
 
   return(invisible())
 }
@@ -372,6 +293,9 @@ DESCRIPTIONfileFromModule <- function(module, md, deps, hasNamespaceFile, NAMESP
 
   d$Imports <- Require::extractPkgName(deps)
   versionNumb <- Require::extractVersionNumber(deps)
+  needRemotes <- which(!is.na(Require::extractPkgGitHub(deps)))
+  d$Remotes <- Require::trimVersionNumber(deps[needRemotes])
+
   hasVersionNumb <- !is.na(versionNumb)
   inequality <- paste0("(", gsub("(.+)\\((.+)\\)", "\\2", deps[hasVersionNumb]), ")")
   missingSpace <- !grepl("[[:space:]]", inequality)
@@ -396,6 +320,7 @@ DESCRIPTIONfileFromModule <- function(module, md, deps, hasNamespaceFile, NAMESP
   d$Imports[hasVersionNumb] <- paste(d$Imports[hasVersionNumb], inequality)
 
   dFile <- filenameFromFunction(packageFolderName, "DESCRIPTION", fileExt = "")
+  origDESCtxt <- read.dcf(dFile)
 
   cat(paste("Package:", d$Package), file = dFile, sep = "\n")
   cat(paste("Type:", d$Type), file = dFile, sep = "\n", append = TRUE)
@@ -405,17 +330,63 @@ DESCRIPTIONfileFromModule <- function(module, md, deps, hasNamespaceFile, NAMESP
   cat(paste("Date:", d$Date), file = dFile, sep = "\n", append = TRUE)
   cat(c("Authors@R:  ", format(d$Authors)), file = dFile, sep = "\n", append = TRUE)
 
-  if (length(d$Imports))
-    cat(c("Imports:", paste("   ", d$Imports, collapse = ",\n")), sep = "\n", file = dFile, append = TRUE)
+  mergeField(origDESCtxt = origDESCtxt, field = d$Imports, fieldName = "Imports", dFile)
 
-  Suggests <- c('knitr', 'rmarkdown')
-  cat(c("Suggests:", paste("   ", Suggests, collapse = ",\n")), sep = "\n", file = dFile, append = TRUE)
+  suggs <- c('knitr', 'rmarkdown', 'testthat', 'withr', 'roxygen2')
+  mergeField(origDESCtxt = origDESCtxt, field = suggs, fieldName = "Suggests", dFile)
+
+  mergeField(origDESCtxt = origDESCtxt, field = d$Remotes, fieldName = "Remotes", dFile)
 
   cat("Encoding: UTF-8", sep = "\n", file = dFile, append = TRUE)
   cat("License: GPL-3", sep = "\n", file = dFile, append = TRUE)
   cat("VignetteBuilder: knitr, rmarkdown", sep = "\n", file = dFile, append = TRUE)
   cat("ByteCompile: yes", sep = "\n", file = dFile, append = TRUE)
   cat("Roxygen: list(markdown = TRUE)", sep = "\n", file = dFile, append = TRUE)
+  cat(paste0("RoxygenNote: ", as.character(packageVersion("roxygen2"))), sep = "\n", file = dFile, append = TRUE)
+
+
   message("New/updated DESCRIPTION file is: ", dFile)
   return(dFile)
 }
+
+mergeField <- function(origDESCtxt, field, dFile, fieldName = "Imports") {
+  fieldVals <- character()
+  if (fieldName %in% colnames(origDESCtxt))
+    fieldVals <- strsplit(origDESCtxt[, fieldName], split = ",+\n")[[1]]
+  if (length(field)) {
+    field <- trimRedundancies(unique(c(field, fieldVals)))
+  }
+  cat(c(paste0(fieldName, ":"), paste("   ", sort(field$packageFullName), collapse = ",\n")),
+      sep = "\n", file = dFile, append = TRUE)
+}
+
+
+
+documentModule <- function(packageFolderName, gpd, linesWithDefModule) {
+  message("Building documentation")
+  m <- packageFolderName
+  tmpSrcForDoc <- file.path(m, "R/READONLYFromMainModuleFile.R")
+  mainModuleFile <- file.path(m, paste0(basename(m), ".R"))
+  # if (missing(rlaa)) {
+  rlaa <- readLines(mainModuleFile)
+  # }
+
+  if (missing(linesWithDefModule)) {
+    if (missing(gpd)) {
+      aa <- parse(mainModuleFile, keep.source = TRUE)
+      gpd <- getParseData(aa)
+    }
+    linesWithDefModule <- gpd[grep("defineModule", gpd$text) - 1, ][, c("line1", "line2")]
+  }
+  if (!dir.exists(file.path(m, "R")))
+    dir.create(file.path(m, "R"))
+  cat(paste0("#% Generated by SpaDES.core: do not edit by hand
+#% Please edit documentation in\n#%", mainModuleFile),
+      file = tmpSrcForDoc)
+  cat(rlaa[-(linesWithDefModule[[1]]:linesWithDefModule[[2]])], sep = "\n",
+      file = tmpSrcForDoc, append = TRUE)
+  # on.exit(unlink(tmpSrcForDoc))
+  roxygen2::roxygenise(m, roclets = NULL) # This builds documentation, but also exports all functions ...
+  pkgload::dev_topic_index_reset(m)
+  pkgload::unload(.moduleNameNoUnderscore(basename2(m))) # so, unload here before reloading without exporting
+}
