@@ -18,23 +18,6 @@
   )
 }
 
-#' Reserved module parameter names
-#'
-#' These are common parameter names that are reserved for specific use within modules.
-#'
-#' - `.plotInitialTime`: the initial time for plotting;
-#' - `.plotInterval`: the interval between plots;
-#' - `.plots`: the types of plots to create (see `types` argument in [Plots()]);
-#' - `.saveInitialTime`: the initial time for saving;
-#' - `.saveInterval`: the interval between saves;
-#' - `.useCache`: whether to use caching, or which events to cache;
-#' - `.useParallel`: whether to use parallel processing, or the number of parallel cores to use;
-#'
-#' @keywords internal
-#' @rdname dot-params
-.knownDotParams <- c(".plotInitialTime", ".plotInterval", ".plots",
-                     ".saveInitialTime", ".saveInterval",
-                     ".useCache", ".useParallel") ## TODO: add others here, e.g. .studyAreaName?
 
 #' @keywords internal
 #' @include environment.R
@@ -329,12 +312,6 @@ all.equal.simList <- function(target, current, ...) {
   })
   rm(list = objNamesTarget, envir = envir(target))
   rm(list = objNamesCurrent, envir = envir(current))
-  # suppressWarnings(rm("._startClockTime", envir = envir(target)))
-  # suppressWarnings(rm("._startClockTime", envir = envir(current)))
-  # suppressWarnings(rm("._firstEventClockTime", envir = envir(target)))
-  # suppressWarnings(rm("._firstEventClockTime", envir = envir(current)))
-  # suppressWarnings(rm(".timestamp", envir = envir(target)))
-  # suppressWarnings(rm(".timestamp", envir = envir(current)))
 
   target1 <- .wrap(target, cachePath = getwd()) # deals with SpatVector/SpatRaster etc.
   current1 <- .wrap(current, cachePath = getwd()) # deals with SpatVector/SpatRaster etc.
@@ -407,3 +384,30 @@ noEventWarning <- function(sim) {
     sep = ""
   )
 }
+
+
+._txtClockTime <- "._clockTime"
+._txtStartClockTime <- "._startClockTime"
+._txtPrevEventTimeFinish <- "._prevEventTimeFinish"
+._txtSimNesting <- "._simNesting"
+._txtDotUseCache <- ".useCache"
+
+#' Reserved module parameter names
+#'
+#' These are common parameter names that are reserved for specific use within modules.
+#'
+#' - `.plotInitialTime`: the initial time for plotting;
+#' - `.plotInterval`: the interval between plots;
+#' - `.plots`: the types of plots to create (see `types` argument in [Plots()]);
+#' - `.saveInitialTime`: the initial time for saving;
+#' - `.saveInterval`: the interval between saves;
+#' - `.useCache`: whether to use caching, or which events to cache;
+#' - `.useParallel`: whether to use parallel processing, or the number of parallel cores to use;
+#'
+#' @keywords internal
+#' @rdname dot-params
+.knownDotParams <- c(".plotInitialTime", ".plotInterval",
+                     ".plots",
+                     ".saveInitialTime", ".saveInterval",
+                     ._txtDotUseCache, ".useParallel") ## TODO: add others here, e.g. .studyAreaName?
+
