@@ -86,6 +86,7 @@ test_that("newModule with events and functions", {
   testInit("ggplot2")
   nm <- "test"
   unlink(dir(Require::tempdir2(), pattern = nm, full.names = TRUE), recursive = TRUE)
+  hello <- "__.H._.E._.L._.L._.O.__"
   newModule(
     nm,
     path = Require::tempdir2(),
@@ -110,6 +111,7 @@ test_that("newModule with events and functions", {
     ),
     func = function(x) {
       message("__.H._.E._.L._.L._.O.__")
+      # message(hello)
     },
     Init = function(sim) {
       sim$dd <- "no way"
@@ -142,15 +144,16 @@ test_that("newModule with events and functions", {
   expect_true(out$a == 2)
   expect_true(out$b == 3)
   yrsSimulated <- (end(out) - start(out))
-  expect_true(sum(grepl("__.H._.E._.L._.L._.O.__", mess, fixed = TRUE)) == yrsSimulated)
-  expect_true(NROW(completed(out)) == yrsSimulated + 6)
+  expect_true(sum(grepl(hello, mess)) == yrsSimulated)
+  expect_true(NROW(completed(out)) == yrsSimulated +
+                (NROW(.coreModules()) - 1) + length(c(".inputObjects", "next1", "init")))
   expect_true(NROW(events(out)) == 1)
   expect_true(NROW(completed(out)[eventType == "next1"]) == 1)
   expect_true(NROW(completed(out)[eventType == "plot"]) == yrsSimulated)
 })
 
 test_that("newModule without path specified as arg", {
-  testInit("ggplot2")
+  testInit("ggplot2", opts = list(spades.debug = 0))
   nm <- "test"
   setPaths(modulePath = file.path(Require::tempdir2(), "lolololo"))
   unlink(dir(getPaths()$modulePath, pattern = nm, full.names = TRUE), recursive = TRUE)
@@ -176,7 +179,7 @@ test_that("newModule without path specified as arg", {
   )
   expect_is(out, "simList")
   expect_identical(out$dd, "no way")
-  expect_true(sum(grepl("init", mess)) == 1)
+  expect_true(sum(grepl("init", mess)) == length(modules(out, hidden = TRUE)))
 
   unlink(dir(getPaths()$modulePath, pattern = nm, full.names = TRUE), recursive = TRUE)
   expect_false(file.exists(file.path(getPaths()$modulePath, nm, paste0(nm, ".R"))))
