@@ -1,3 +1,89 @@
+test_that("simulation runs with new Cache chaining", {
+  skip_on_cran() # too long
+  testInit(sampleModReqdPkgs)
+  withr::local_options(reproducible.useMemoise = TRUE,
+                       spades.cacheChaining = TRUE)
+
+  set.seed(42)
+  times <- list(start = 0.0, end = 2, timeunit = "year")
+  params <- list(
+    .globals = list(burnStats = "npixelsburned", stackName = "landscape",
+                    .useCache = c(".inputObjects", "init", "move",
+                                  "burn", "stats")),
+    randomLandscapes = list(.plotInitialTime = NA, .plotInterval = NA, .seed = list("init" = 321)),
+    caribouMovement = list(.plotInitialTime = NA, .plotInterval = NA, torus = TRUE),
+    fireSpread = list(.plotInitialTime = NA, .plotInterval = NA)
+  )
+  modules <- list("randomLandscapes", "caribouMovement",
+                  "fireSpread")
+  paths <- list(modulePath = getSampleModules(tmpdir))
+
+
+  set.seed(123)
+  #devtools::load_all("~/GitHub/reproducible")
+  #devtools::load_all("~/GitHub/SpaDES.core")
+
+  useCaches <- list(
+    c(".inputObjects", "init"),
+    c(".inputObjects", "init", "stats"),
+    c(".inputObjects", "init", "stats", "burn"),
+    c(".inputObjects", "init",  "stats", "burn", "move")
+  )
+
+  me <- chainingEnv(getOption("reproducible.cachePath"))
+  me$eventCachingDF <- NULL # make sure it is empty
+
+
+  mess <- mySims <- test <- testEvalPostEvent <- list()
+  opts11 <- list()
+  op1 <- getOption("spades.evalPostEvent")
+  on.exit(options(spades.evalPostEvent = op1))
+  for (useCache in useCaches) {
+    for (i in 1:2) { # need to run twice to set the Cache each time
+      opts11[[i]] <- options(
+        spades.evalPostEvent = quote(message(paste('ThisMess', .robustDigest(sim$landscape))))
+      )
+      params$.globals = list(burnStats = "npixelsburned", stackName = "landscape",
+                             .useCache = useCache)
+      iter <- paste0(paste(useCache, collapse = "_"), "_", i)
+      mess[[iter]] <-
+        capture_messages(mySims[[iter]] <- simInit(times, params, modules,
+                                                   objects = list(), paths) |>
+                           spades(debug = TRUE, .plotInitialTime = NA))
+      test[[iter]] <- grep("cacheId passed to override", mess[[iter]])
+      testEvalPostEvent[[iter]] <- length(grep("ThisMess", mess[[iter]])) ==
+        (NROW(completed(mySims[[iter]])) -
+           length(modules(mySims[[iter]])) +  # rm all 3 .inputObjects
+           1 - # just 1 .inputObjects
+           length(.coreModules()) + 1 ) # restartR is not used
+    }
+  }
+
+  expects <- c(.inputObjects_init_1 = 0L, .inputObjects_init_2 = 2L,
+               .inputObjects_init_stats_1 = 2L,
+               .inputObjects_init_stats_2 = 2L,
+               .inputObjects_init_stats_burn_1 = 2L,
+               .inputObjects_init_stats_burn_2 = 3L,
+               .inputObjects_init_stats_burn_move_1 = 3L,
+               .inputObjects_init_stats_burn_move_2 = 19L)
+  expect_identical(lengths(test), expects)
+  expect_true(all(unlist(testEvalPostEvent)))
+
+  env <- environment()
+  opts111 <- options(
+    spades.evalPostEvent = quote({a <- data.frame(b = 1:10, d = 1:10);
+                                 gg <- ggplot2::ggplot(a) + ggplot2::geom_point(ggplot2::aes(x = b, y = d))
+                                 assign("gg", gg, envir = SpaDES.core:::.pkgEnv)})
+  )
+  times <- list(start = 0.0, end = 0, timeunit = "year")
+  messy <- capture_messages(si <- simInit(times, params, modules,
+                                             objects = list(), paths) |>
+                     spades(debug = TRUE, .plotInitialTime = NA))
+  expect_true(is(.pkgEnv$gg, "gg"))
+  rm(list = "gg", envir = SpaDES.core:::.pkgEnv)
+
+})
+
 test_that("simulation runs with simInit and spades with set.seed; events arg", {
   skip_on_cran() # too long
   testInit(sampleModReqdPkgs)
@@ -36,7 +122,7 @@ test_that("simulation runs with simInit and spades with set.seed; events arg", {
   set.seed(123)
   mySimEvent <- simInit(times, params, modules, objects = list(), paths) |>
     spades(debug = FALSE, .plotInitialTime = NA, events = "init")
-  expect_true(all("init" == completed(mySimEvent)$eventType))
+  expect_true(all(c(".inputObjects", "init") %in% completed(mySimEvent)$eventType))
   expect_true(max(events(mySimEvent)$eventTime) <= end(mySimEvent)) # didn't schedule next event
 
 
@@ -54,8 +140,8 @@ test_that("simulation runs with simInit and spades with set.seed; events arg", {
   eventTypes <- c("nothing")
   mySimEvent4 <- simInit(times, params, modules, objects = list(), paths) |>
     spades(debug = FALSE, .plotInitialTime = NA, events = eventTypes)
-  expect_true(NROW(completed(mySimEvent4)) == 0) # nothing completed
-  expect_true(all("init" == events(mySimEvent4)$eventType)) # nothing happened; only inits in queue
+  expect_true(NROW(completed(mySimEvent4)) == length(modules)) # only .inputObjects completed
+  expect_true(all(c(".inputObjects", "init") %in% completed(mySimEvent)$eventType))
 
   eventTypes <- list(randomLandscapes = c("init"),
                      fireSpread = c("init", "burn")
@@ -72,33 +158,41 @@ test_that("simulation runs with simInit and spades with set.seed; events arg", {
   mySimEvent6 <- simInit(times, params, modules, objects = list(), paths) |>
     spades(debug = FALSE, .plotInitialTime = NA, events = eventTypes)
   expect_true(all("randomLandscapes" %in% completed(mySimEvent6)$moduleName))
-  expect_true(!all("fireSpread" %in% completed(mySimEvent6)$moduleName)) # didn't run any fireSpread events b/c misspelled
+  expect_true(sum("fireSpread" %in% completed(mySimEvent6)$moduleName) == 1) # only .inputObjects; didn't run any fireSpread events b/c misspelled
   expect_true(all("fireSpread" %in% events(mySimEvent6)$moduleName)) # didn't run any fireSpread events b/c misspelled
 
   mySimEvent7 <- simInit(times, params, modules, objects = list(), paths) |>
     spades(debug = FALSE, .plotInitialTime = NA, events = eventTypes, cache = TRUE)
-  expect_true(all("randomLandscapes" %in% completed(mySimEvent7)$moduleName))
-  expect_true(!all("fireSpread" %in% completed(mySimEvent7)$moduleName)) # didn't run any fireSpread events b/c misspelled
+  compped <- completed(mySimEvent7)
+  compped <- compped[!compped$eventType %in% ".inputObjects"]
+  expect_true(all("randomLandscapes" %in% compped$moduleName))
+  expect_true(!all("fireSpread" %in% compped$moduleName)) # didn't run any fireSpread events b/c misspelled
   expect_true(all("fireSpread" %in% events(mySimEvent7)$moduleName)) # didn't run any fireSpread events b/c misspelled
 
   mySimEvent8 <- simInit(times, params, modules, objects = list(), paths) |>
     spades(debug = FALSE, .plotInitialTime = NA, events = eventTypes, cache = TRUE)
-  expect_true(all("randomLandscapes" %in% completed(mySimEvent8)$moduleName))
-  expect_true(!all("fireSpread" %in% completed(mySimEvent8)$moduleName)) # didn't run any fireSpread events b/c misspelled
+  compped <- completed(mySimEvent8)
+  compped <- compped[!compped$eventType %in% ".inputObjects"]
+  expect_true(all("randomLandscapes" %in% compped$moduleName))
+  expect_true(!all("fireSpread" %in% compped$moduleName)) # didn't run any fireSpread events b/c misspelled
   expect_true(all("fireSpread" %in% events(mySimEvent8)$moduleName)) # didn't run any fireSpread events b/c misspelled
 
   mySimEvent9 <- simInitAndSpades(times, params, modules, objects = list(), paths,
                         debug = FALSE, .plotInitialTime = NA, events = "init")
-  expect_true(all("init" == completed(mySimEvent9)$eventType))
+  compped <- completed(mySimEvent9)
+  compped <- compped[!compped$eventType %in% ".inputObjects"]
+  expect_true(all("init" == compped$eventType))
   expect_true(max(events(mySimEvent9)$eventTime) <= end(mySimEvent9)) # didn't schedule next event
 
   # Test times
   #  Set end time to WAY after the init events
   mySimEvent10 <- simInitAndSpades(times = list(start = 0, end = 10), params, modules, objects = list(), paths,
                                   debug = FALSE, .plotInitialTime = NA, events = "init")
+  compped <- completed(mySimEvent10)
+  compped <- compped[!compped$eventType %in% ".inputObjects"]
   expect_true(time(mySimEvent10) == end(mySimEvent10)) # it is at 10, the end
-  expect_true(all("init" == completed(mySimEvent10)$eventType))
-  expect_true(max(completed(mySimEvent10)$eventTime) == start(mySimEvent10)) # didn't go past start time because init are all at start
+  expect_true(all("init" == compped$eventType))
+  expect_true(max(compped$eventTime) == start(mySimEvent10)) # didn't go past start time because init are all at start
   simOut <- spades(mySimEvent10)
   expect_true(time(simOut) == end(simOut)) # it is at 10, the end
   expect_true(!all("init" == completed(simOut)$eventType))
@@ -134,7 +228,7 @@ test_that("spades calls - diff't signatures", {
 
   a <- simInit()
   a1 <- Copy(a)
-  opts <- options(spades.saveSimOnExit = FALSE)
+  opts <- withr::local_options(spades.saveSimOnExit = FALSE)
   expect_message(spades(a, debug = TRUE), "eventTime")
   expect_silent(expect_message(spades(a, debug = FALSE), "DTthreads"))
   expect_silent(expect_message(spades(a, debug = FALSE, .plotInitialTime = NA), "DTthreads"))
@@ -147,7 +241,7 @@ test_that("spades calls - diff't signatures", {
 
   if (requireNamespace("logging", quietly = TRUE)) {
     expect_message(spades(Copy(a), debug = list(debug = list("current", "events")), .plotInitialTime = NA),
-        "eventTime *moduleName *eventType *eventPriority")
+                   "eventTime *moduleName *eventType *eventPriority")
   } else {
     expect_message(spades(Copy(a), debug = list(debug = list("current", "events")), .plotInitialTime = NA),
                    "eventTime *moduleName *eventType *eventPriority")
@@ -161,7 +255,7 @@ test_that("spades calls - diff't signatures", {
     suppressWarnings(expect_output(spades(a, progress = "text", debug = TRUE), "20%"))
     suppressWarnings(expect_output(spades(a, progress = "text"), "..........| 100%"))
   }
-  opts <- options(spades.saveSimOnExit = FALSE)
+  opts <- withr::local_options(spades.saveSimOnExit = FALSE)
   expect_silent(expect_message(spades(a, debug = FALSE, progress = FALSE), "DTthreads"))
   expect_silent(expect_message(spades(a, debug = FALSE, progress = "rr"), "DTthreads"))
   opts <- options(opts)
@@ -225,7 +319,7 @@ test_that("simInit with R subfolder scripts", {
 })
 
 test_that("simulation runs with simInit with duplicate modules named", {
-  testInit(sampleModReqdPkgs)
+  testInit(sampleModReqdPkgs, opts = list(spades.debug = 1))
 
   set.seed(42)
 
@@ -387,9 +481,9 @@ test_that("simulation runs with simInit with duplicate modules named", {
   #
   # summary(a2)[, "median"]/summary(a3)[, "median"]
   #
-  # ########################################
+  #
   # # With 2 modules, therefore sorting
-  # ########################################
+  #
   # modules <- list("test", "test2")
   # mySim <- simInit(times = times, params = parameters, modules = modules,
   #                  objects = objects, paths = paths)
@@ -407,7 +501,7 @@ test_that("simulation runs with simInit with duplicate modules named", {
 })
 
 test_that("conflicting function types", {
-  testInit(sampleModReqdPkgs, smcc = TRUE)
+  testInit(sampleModReqdPkgs, smcc = TRUE, opts = list(spades.debug = 1))
 
   m <- "child4"
   newModule(m, tmpdir, open = FALSE)
@@ -486,14 +580,15 @@ test_that("conflicting function types", {
   mm <- capture_messages(simInit(paths = list(modulePath = tmpdir), modules = m))
 
   fullMessage <- c(# "defineParameter: 'value' is not of specified type 'numeric'",
-                   "defineParameter: 'plotInterval' is not of specified type 'numeric'",
-                   "defineParameter: 'saveInitialTime' is not of specified type 'numeric'",
-                   "defineParameter: 'saveInterval' is not of specified type 'numeric'",
-                   "child4: module code: Init: local variable.*qwerqwer.*assigned but may not be used",
-                   "Running .inputObjects for child4",
-                   "child4: module code: Init: local variable.*poiuoiu.*assigned but may not be used",
-                   "child4: outputObjects: g, g1 are assigned to sim inside Init, but are not declared in metadata outputObjects",
-                   "child4: inputObjects: b, d, f, d1, test are used from sim inside Init, but are not declared in metadata inputObjects"
+    "defineParameter: 'plotInterval' is not of specified type 'numeric'",
+    "defineParameter: 'saveInitialTime' is not of specified type 'numeric'",
+    "defineParameter: 'saveInterval' is not of specified type 'numeric'",
+    "child4: module code: Init: local variable.*qwerqwer.*assigned but may not be used",
+    grepDotInputObjectsModule("child4"),
+    # "Running .inputObjects for child4",
+    "child4: module code: Init: local variable.*poiuoiu.*assigned but may not be used",
+    "child4: outputObjects: g, g1 are assigned to sim inside Init, but are not declared in metadata outputObjects",
+    "child4: inputObjects: b, d, f, d1, test are used from sim inside Init, but are not declared in metadata inputObjects"
   )
 
   mm <- cleanMessage(mm)
@@ -541,8 +636,8 @@ test_that("conflicting function types", {
                         pattern = c(paste0(m, ": module code: b is declared in metadata outputObjects|",
                                            "so not checking minimum package|",
                                            m, ": module code: a is declared in metadata inputObjects|",
-                                           "Running .inputObjects|",
-                                           "Setting:|Paths set to:|",
+                                           grepDotInputObjectsModule(m), #"Running .inputObjects|",
+                                           "|Setting:|Paths set to:|",
                                            "Using setDTthreads|",
                                            m, ": using dataPath|", "Elapsed")))))
 
@@ -603,7 +698,7 @@ test_that("conflicting function types", {
       url1 <- extractURL('ei4', sim = sim)
       if (!identical(url1, 'test.com'))
         stop('extractURL without module fails')",
-paste0("      url1 <- extractURL('ei4', sim = sim, module = \"", m, "\")") ,"
+      paste0("      url1 <- extractURL('ei4', sim = sim, module = \"", m, "\")") ,"
       if (!identical(url1, 'test.com'))
         stop('extractURL fails')
       sim$g <- 1
@@ -617,7 +712,8 @@ paste0("      url1 <- extractURL('ei4', sim = sim, module = \"", m, "\")") ,"
       sep = "\n", fill = FALSE, file = fileName)
 
   fullMessage <- c(
-    "Running .inputObjects for child4",
+    grepDotInputObjectsModule("child4"),
+    # "Running .inputObjects for child4",
     "child4: module code: co2, co3 are declared in metadata outputObjects, but are not assigned in the module",
     "child4: module code: ei2, ei3, ei4 are declared in metadata inputObjects, but no default\\(s\\) are provided in .inputObjects",
     "child4: module code: ei3 is declared in metadata inputObjects, but is not used in the module",
@@ -637,7 +733,6 @@ paste0("      url1 <- extractURL('ei4', sim = sim, module = \"", m, "\")") ,"
   md2 <- moduleMetadata(path = getSampleModules(tmpdir),
                         module = "randomLandscapes")
 
-
   mm <- capture_messages({
     mySim <- simInit(paths = list(modulePath = tmpdir), modules = m)
   })
@@ -683,14 +778,14 @@ test_that("scheduleEvent with NA logical in a non-standard parameter", {
   # show that it is logical
   sim <- simInit(times = list(start = 0, end = 2))
   expect_true(is.numeric(eval(xxx3)$default[[1]]))
-
   mm <- capture_messages(simInit(paths = list(modulePath = tmpdir), modules = m))
-  expect_true(all(unlist(lapply(c("Running .inputObjects", "module code appears clean"),
+  expect_true(all(unlist(lapply(c(grepDotInputObjectsModule(m),#"Running .inputObjects",
+                                  "module code appears clean"),
                                 function(x) any(grepl(mm, pattern = x))))))
 })
 
 test_that("messaging with multiple modules", {
-  testInit("ggplot2", smcc = TRUE)
+  testInit("ggplot2", smcc = TRUE, opts = list(spades.debug = TRUE))
 
   m1 <- "test"
   m2 <- "test2"
@@ -793,7 +888,8 @@ test_that("messaging with multiple modules", {
   fullMessage <- c(
     # "defineParameter: 'plotInitialTime' is not of specified type 'character'",
     "defineParameter: 'saveInitialTime' is not of specified type 'character'",
-    "Running .inputObjects for test",
+    grepDotInputObjectsModule("test"),
+    # "Running .inputObjects for test",
     "test: module code: co2, co3 are declared in metadata outputObjects, but are not assigned in the module",
     "test: module code: ei2, ei3, ei4 are declared in metadata inputObjects, but no default\\(s\\) are provided in .inputObjects",
     "test: module code: ei3 is declared in metadata inputObjects, but is not used in the module",
@@ -806,7 +902,8 @@ test_that("messaging with multiple modules", {
     "test: inputObjects: b, aaa are used from sim inside Init, but are not declared in metadata inputObjects",
     "test: inputObjects: b, co3 are used from sim inside .inputObjects, but are not declared in metadata inputObjects",
     # "defineParameter: 'plotInitialTime' is not of specified type 'character'",
-    "Running .inputObjects for test2",
+    grepDotInputObjectsModule("test2"),
+    # "Running .inputObjects for test2",
     "test2: module code: co1, co4 are declared in metadata outputObjects, but are not assigned in the module",
     "test2: module code: ei1, ei4 are declared in metadata inputObjects, but no default\\(s\\) are provided in .inputObjects",
     "test2: module code: ei1 is declared in metadata inputObjects, but is not used in the module",
@@ -817,9 +914,11 @@ test_that("messaging with multiple modules", {
     "test2: inputObjects: b is used from sim inside .inputObjects, but is not declared in metadata inputObjects",
     # "defineParameter: 'plotInitialTime' is not of specified type 'character'",
     "defineParameter: 'hello' is not of specified type 'character'",
-    "Running .inputObjects for test3",
+    grepDotInputObjectsModule("test3"),
+    # "Running .inputObjects for test3",
     "test3: module code appears clean",
-    "Running .inputObjects for test4",
+    grepDotInputObjectsModule("test4"),
+    # "Running .inputObjects for test4",
     "test4: module code appears clean"
   )
 
@@ -882,11 +981,13 @@ test_that("Module code checking -- pipe with matrix product with backtick & data
   mm <- cleanMessage(mm)
 
   fullMessage1 <- c(
-    "Running .inputObjects for child4",
+    grepDotInputObjectsModule("child4"),
+    # "Running .inputObjects for child4",
     "child4: module code: Init: local variable.*result1.*assigned but may not be used ",
     "child4: outputObjects: bvcx, bvcx2, b, a are assigned to sim inside Init, but are not declared in metadata outputObjects")
   fullMessageNonInteractive <- c(
-    "Running .inputObjects for child4",
+    grepDotInputObjectsModule("child4"),
+    # "Running .inputObjects for child4",
     "child4: module code: Init", cantCodeCheckMessage, "'sim\\$bvcx <- matrix.*", #possibly at .*147",
     "child4: module code: Init", cantCodeCheckMessage, "'sim\\$bvcx2 <- matrix.*", #possibly at .*148",
     "child4: module code: Init: local variable.*result1.*assigned but may not be used",
@@ -1022,7 +1123,7 @@ test_that("debug using logging", {
         mySim2 <- spades(Copy(mySim),
                          debug = list("console" = list(level = "INFO"), debug = 1),
                          .plotInitialTime = NA)
-        })
+      })
     })
   })
   expect_true(length(mess1) == 0)
@@ -1037,3 +1138,64 @@ test_that("debug using logging", {
   })
   expect_true(length(mess1) == 0)
 })
+
+test_that("options('reproducible.reqdPkgsDontLoad", {
+  dontLoad <- "logging" # ggplot2 has many rev deps; can't be sp, raster because already loaded
+
+  skip_if_not_installed(dontLoad)
+  unloadNamespace(dontLoad)
+  withr::local_options(spades.reqdPkgsDontLoad = dontLoad)
+
+  testInit()
+
+  newModule("test", tmpdir, open = FALSE)
+
+  # Sept 18 2018 -- Changed to use "seconds" -- better comparison with simple loop
+  cat(file = file.path(tmpdir, "test", "test.R"), '
+    defineModule(sim, list(
+    name = "test",
+    description = "insert module description here",
+    keywords = c("insert key words here"),
+    authors = person(c("Eliot", "J", "B"), "McIntire", email = "eliot.mcintire@nrcan-rncan.gc.ca", role = c("aut", "cre")),
+    childModules = character(0),
+    version = list(SpaDES.core = "0.1.0", test = "0.0.1"),
+    spatialExtent = terra::ext(rep(0, 4)),
+    timeframe = as.POSIXlt(c(NA, NA)),
+    timeunit = "year",
+    citation = list("citation.bib"),
+    documentation = list("README.md", "test.Rmd"),',
+paste0("    reqdPkgs = list(\'", dontLoad, "\'),"),'
+    parameters = rbind(
+    ),
+    inputObjects = bindrows(
+    ),
+    outputObjects = bindrows(
+    )
+    ))
+
+    doEvent.test = function(sim, eventTime, eventType, debug = FALSE) {
+    switch(
+    eventType,
+    init = {
+    })
+    return(invisible(sim))
+    }
+
+', fill = TRUE)
+  expect_false(isNamespaceLoaded(dontLoad))
+  warn <- capture_warnings(
+    sim <- simInit(modules = "test", paths = list(modulePath = tmpdir),
+                   times = list(start = 0, end = 1, timeunit = "year"))
+  )
+  expect_false(isNamespaceLoaded(dontLoad))
+
+  withr::local_options(spades.reqdPkgsDontLoad = NULL)
+  warn <- capture_warnings(
+    sim <- simInit(modules = "test", paths = list(modulePath = tmpdir),
+                   times = list(start = 0, end = 1, timeunit = "year"))
+  )
+  expect_true(isNamespaceLoaded(dontLoad))
+  unloadNamespace(dontLoad)
+
+})
+
